pytest: Simple powerful testing with Python
===========================================

Description
-----------

Simple powerful testing with Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/pytest/

